# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/01_base.ipynb.

# %% auto 0
__all__ = ['TREEKWS', 'Xath', 'Path', 'File', 'Dir']

# %% ../nbs/01_base.ipynb 6
import pathlib

# %% ../nbs/01_base.ipynb 8
#| export


# %% ../nbs/01_base.ipynb 10
from atyp import StrQ

from nchr import DOT
from nlit import (BASE, LEAF, PATH, NAME, TREE, PathKind, ABRV, DESC, )

from pstr.util import toprivate

# %% ../nbs/01_base.ipynb 12
from psrc import fullpath, aspath, ListDir

# %% ../nbs/01_base.ipynb 14
from .mxns.plib import PathLibMixin
from .mxns.kind import FileKindMixin, DirKindMixin

# %% ../nbs/01_base.ipynb 16
_NAME, _TREE = tuple(map(toprivate, (NAME, TREE)))
TREEKWS = f'{TREE}kws'

# %% ../nbs/01_base.ipynb 17
class Xath(ListDir, PathLibMixin):
    pkind: str = PathKind.PATH
    aspec: tuple = (PATH, NAME, ABRV, DESC, TREEKWS, )
    inherit_aspec = True
    
    @property
    def kind(self) -> str: return str(self.pkind)
    @property
    def full(self) -> pathlib.Path: return fullpath(self.path)

    @property
    def name(self) -> str: return getattr(self, _NAME, self.stem)
    @name.setter
    def name(self, name: str): setattr(self, _NAME, name)

    @property
    def pathname(self): return self.path.name
    
    @property
    def tree(self) -> ListDir: return getattr(self, _TREE, ListDir(self.path, **getattr(self, TREEKWS, dict())))
    @tree.setter
    def tree(self, tree: str):
        tree = tree if isinstance(tree, ListDir) else ListDir(tree, **getattr(self, TREEKWS, dict()))
        setattr(self, _TREE, tree)
    @tree.deleter
    def tree(self): self._tree = None

    def __new__(cls, path: StrQ = None, *args, **kwargs):
        return super().__new__(cls, aspath(path))
    
    def __init__(
        self, path: StrQ = None, name: StrQ = None, 
        abrv: StrQ = None, desc: StrQ = None, 
        *args, **kwargs        
    ):
        self.path = (path or self.path)
        self.name = (name or self.pathname)
        self.abrv = abrv
        self.desc = desc
        self.treekws = kwargs.pop(TREEKWS, dict())
        self.tree = self.path

    def update(self, **kwargs):
        path = kwargs.pop(PATH, self)
        base = kwargs.pop(BASE, getattr(self, BASE, pathlib.Path(DOT)))
        leaf = kwargs.pop(LEAF, getattr(self, LEAF, pathlib.Path(DOT)))
        kwds = dict(leaf=leaf, base=base, path=path, **kwargs)
        return super().update(**kwds)

    def makecopy(self, *args, **kwargs):        
        kwds = self.getattrs(**kwargs)
        path = kwds.pop(PATH, self)
        new = type(self)(path, *args, **kwds)
        return new
    
    def view(self, **kwargs):
        self.tree.view(**kwargs)

# %% ../nbs/01_base.ipynb 22
class Path(Xath):
    '''Path Entry'''
    ...

# %% ../nbs/01_base.ipynb 24
class File(FileKindMixin, Path):
    '''File Entry'''

# %% ../nbs/01_base.ipynb 26
class Dir(DirKindMixin, Path):
    '''Dir Entry'''



# AUTOGENERATED! DO NOT EDIT! File to edit: ../../nbs/mxns/04_kind.ipynb.

# %% auto 0
__all__ = ['FileKindMixin', 'DirKindMixin']

# %% ../../nbs/mxns/04_kind.ipynb 6
import os, pathlib
from abc import abstractmethod

# %% ../../nbs/mxns/04_kind.ipynb 8
from typing import Callable, Optional

# %% ../../nbs/mxns/04_kind.ipynb 10
from atyp import PathType
from nlit import (PathKind, NAME)

from chck.path import ispath

# %% ../../nbs/mxns/04_kind.ipynb 12
#| export


# %% ../../nbs/mxns/04_kind.ipynb 15
class FileKindMixin:
    pkind: PathKind = PathKind.FILE
    file: PathType

    @property
    def filename(self): 
        return self.file.name if ispath(self.file) or hasattr(self, NAME) else self.file

# %% ../../nbs/mxns/04_kind.ipynb 17
class DirKindMixin:
    pkind: PathKind = PathKind.DIR
    dir: PathType

    @property
    def dirname(self): return self.dir.name



# AUTOGENERATED! DO NOT EDIT! File to edit: ../../nbs/mxns/02_reqr.ipynb.

# %% auto 0
__all__ = ['RequiredMixin']

# %% ../../nbs/mxns/02_reqr.ipynb 6
import os, pathlib

# %% ../../nbs/mxns/02_reqr.ipynb 8
from typing import Callable, Optional

# %% ../../nbs/mxns/02_reqr.ipynb 10
from nlit import (REQUIRED, )

# %% ../../nbs/mxns/02_reqr.ipynb 12
#| export


# %% ../../nbs/mxns/02_reqr.ipynb 14
class RequiredMixin:
    required: bool = True
    aspec: tuple = (REQUIRED, )
    inherit_aspec: bool = True
    
    @property
    def optional(self) -> bool: return not self.required
    @optional.setter
    def optional(self, bval: bool): self.required = not bool(bval)

    def isvalid(self) -> bool:
        return self.exists() if self.required else True



# AUTOGENERATED! DO NOT EDIT! File to edit: ../../nbs/mxns/03_data.ipynb.

# %% auto 0
__all__ = ['DataMixin']

# %% ../../nbs/mxns/03_data.ipynb 6
import os, pathlib
from abc import abstractmethod

# %% ../../nbs/mxns/03_data.ipynb 8
from typing import Callable, Optional

# %% ../../nbs/mxns/03_data.ipynb 10
#| export


# %% ../../nbs/mxns/03_data.ipynb 12
#| export


# %% ../../nbs/mxns/03_data.ipynb 14
class DataMixin:
    @abstractmethod
    def load(self): ...



# AUTOGENERATED! DO NOT EDIT! File to edit: ../../nbs/mxns/00__init__.ipynb.

# %% auto 0
__all__ = []

# %% ../../nbs/mxns/00__init__.ipynb 3
from itertools import chain
from . import plib, reqr, data, kind, expt
from .plib import *
from .reqr import *
from .data import *
from .kind import *
from .expt import *

# %% ../../nbs/mxns/00__init__.ipynb 4
__all__ = sorted(set(chain(*[
    mod.__all__ for mod in (plib, reqr, data, kind, expt, )
])))



# AUTOGENERATED! DO NOT EDIT! File to edit: ../../nbs/plib/00__init__.ipynb.

# %% auto 0
__all__ = []

# %% ../../nbs/plib/00__init__.ipynb 3
from itertools import chain
from . import lib as pathlib, psx as posixpath, wdx as ntpath
from .lib import *
from .psx import *
from .wdx import *

# %% ../../nbs/plib/00__init__.ipynb 4
__all__ = sorted(set(chain(*[
    mod.__all__ for mod in (pathlib, posixpath, ntpath, )
])))



# AUTOGENERATED! DO NOT EDIT! File to edit: ../../nbs/mxns/05_expt.ipynb.

# %% auto 0
__all__ = ['ExpectedMixin']

# %% ../../nbs/mxns/05_expt.ipynb 6
import os, pathlib
from abc import abstractmethod

# %% ../../nbs/mxns/05_expt.ipynb 8
from typing import Callable, Optional, Iterable

# %% ../../nbs/mxns/05_expt.ipynb 10
from atyp import PathType
from nlit import (PathKind, )

from chck.path import ispath

# %% ../../nbs/mxns/05_expt.ipynb 12
from .reqr import RequiredMixin

# %% ../../nbs/mxns/05_expt.ipynb 14
class ExpectedMixin(RequiredMixin):
    aspec: tuple = ('expected', )
    expected: tuple['ExpectedMixin', ... ] = ()
    
    def makeprops(self, **kwargs):
        for i, e in enumerate(self.expected):
            setattr(type(self), e.name, property(lambda self: self.expected[i]))

    def __init__(self, path: PathType, *args, **kwargs):
        super().__init__(path, *args, **kwargs)
        self.makeprops()


    def isvalid(self) -> bool: 
        if not self.required: return True
        return self.path.exists() and all((self.path / e).exists() for e in self.expected)



# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/02_leaf.ipynb.

# %% auto 0
__all__ = ['LeafXath', 'LeafPath', 'LeafFile', 'LeafDir']

# %% ../nbs/02_leaf.ipynb 6
import pathlib

# %% ../nbs/02_leaf.ipynb 8
#| export


# %% ../nbs/02_leaf.ipynb 10
from atyp import StrQ

from nchr import DOT
from nlit import (BASE, LEAF, PATH, PathKind, )

from pstr.util import toprivate

# %% ../nbs/02_leaf.ipynb 12
from psrc.util import aspath
from psrc.leaf import trimleaf, joinleaf, normleaf

# %% ../nbs/02_leaf.ipynb 14
from .base import Xath, Path, File, Dir
from .mxns.kind import FileKindMixin, DirKindMixin

# %% ../nbs/02_leaf.ipynb 16
_BASE, _LEAF, _PATH = tuple(map(toprivate, (BASE, LEAF, PATH)))

# %% ../nbs/02_leaf.ipynb 17
class LeafXath(Xath):
    aspec: tuple = ( LEAF, BASE, )
    
    @property
    def leaf(self) -> pathlib.Path: return getattr(self, _LEAF, pathlib.Path(DOT))
    @leaf.setter
    def leaf(self, leaf: pathlib.Path):
        self._leaf = aspath(leaf)
        self.base = trimleaf(self.path, self.leaf) # Update base to respect new leaf
        self.path = joinleaf(self.path, self.leaf) # Recompute path = base / leaf

    @property
    def base(self) -> pathlib.Path: return getattr(self, _BASE, pathlib.Path(DOT))
    @base.setter
    def base(self, path: pathlib.Path):
        self._base = trimleaf(path, self.leaf)      # Ensure base doesn't include leaf
        self._path = joinleaf(self.base, self.leaf) # Recompute path = base / leaf

    @property
    def path(self) -> pathlib.Path: return getattr(self, _PATH, pathlib.Path(DOT))
    @path.setter
    def path(self, path: str):
        path, leaf = normleaf(path, self.leaf)
        self._base = trimleaf(path, self.leaf)
        self._path = joinleaf(self.base, self.leaf)

    def canbechild(self, other: str) -> bool: 
        return False if self.kind == str(PathKind.FILE) else True
    
    def canbeparent(self, other: str) -> bool:
        otype = other.kind if isinstance(other, type(self)) else str(PathKind.PATH)
        return False if otype == str(PathKind.FILE) else True
    
    def __truediv__(self, other):
        if self.canbeparent(other): return super().__truediv__(other)
        raise ValueError(f'{self.name} cannot be parent of {other}')

    def __rtruediv__(self, other):
        if self.canbechild(other): return super().__rtruediv__(other)
        raise ValueError(f'{self.name} cannot be child of {other}')
    
    def __init__(self, path: StrQ = None, leaf: StrQ = None, *args, **kwargs):
        base, leaf = normleaf(path, leaf or self.leaf)
        self.leaf = leaf
        self.base = trimleaf(base, leaf)
        self.path = joinleaf(self.base, self.leaf)
        
        kwargs.update(leaf=leaf, base=base)
        super().__init__(self.path, *args, **kwargs)

# %% ../nbs/02_leaf.ipynb 19
class LeafPath(LeafXath): 
    ...

# %% ../nbs/02_leaf.ipynb 21
class LeafFile(FileKindMixin, LeafPath): 
    file: str = File('')

# %% ../nbs/02_leaf.ipynb 23
class LeafDir(DirKindMixin, LeafPath):
    dir: str = Dir('')



# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/05_name.ipynb.

# %% auto 0
__all__ = ['NamedXath', 'NamedPath', 'NamedFile', 'NamedDir']

# %% ../nbs/05_name.ipynb 6
#| export


# %% ../nbs/05_name.ipynb 8
#| export


# %% ../nbs/05_name.ipynb 10
from atyp import StrQ

# %% ../nbs/05_name.ipynb 12
#| export


# %% ../nbs/05_name.ipynb 14
from .mxns.kind import FileKindMixin, DirKindMixin
from .data import DataXath, DataPath, DataFile, DataDir

# %% ../nbs/05_name.ipynb 16
class NamedXath(DataXath):
    def __init__(
        self,
        path: StrQ = None, leaf: StrQ = None, name: StrQ = None,
        abrv: StrQ = None, desc: StrQ = None, *args, **kwargs        
    ):
        kwargs.update(leaf=leaf, name=name, abrv=abrv, desc=desc)
        super().__init__(path, *args, **kwargs)

# %% ../nbs/05_name.ipynb 18
class NamedPath(NamedXath):
    ...

# %% ../nbs/05_name.ipynb 20
class NamedFile(FileKindMixin, NamedPath):
    file: DataFile()    

# %% ../nbs/05_name.ipynb 22
class NamedDir(DirKindMixin, NamedPath):
    dir: DataDir()



# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/04_data.ipynb.

# %% auto 0
__all__ = ['DataXath', 'DataPath', 'DataFile', 'DataDir']

# %% ../nbs/04_data.ipynb 6
#| export


# %% ../nbs/04_data.ipynb 8
#| export


# %% ../nbs/04_data.ipynb 10
#| export


# %% ../nbs/04_data.ipynb 12
#| export


# %% ../nbs/04_data.ipynb 14
from .expt import ExpectedXath, ExpectedPath, ExpectedDir, ExpectedFile
from .mxns.data import DataMixin
from .mxns.kind import FileKindMixin, DirKindMixin

# %% ../nbs/04_data.ipynb 16
class DataXath(ExpectedXath, DataMixin):
    ...

# %% ../nbs/04_data.ipynb 18
class DataPath(DataXath):
    ...

# %% ../nbs/04_data.ipynb 20
# NOTE: could alternatively be defined as `class DataFile(ExpectedFile, DataPath):`
class DataFile(FileKindMixin, DataPath):
    file: ExpectedFile()    

# %% ../nbs/04_data.ipynb 22
class DataDir(DirKindMixin, DataPath):
    dir: ExpectedDir()



__version__ = "0.0.5"
# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/00__init__.ipynb.

# %% auto 0
__all__ = []

# %% ../nbs/00__init__.ipynb 3
from itertools import chain
from . import plib, mxns, base, leaf, expt, data, name

from .mxns import *
from .base import *
from .leaf import *
from .expt import *
from .data import *
from .name import *


# %% ../nbs/00__init__.ipynb 4
__all__ = sorted(set(chain(*[
    mod.__all__ for mod in (mxns, base, leaf, expt, data, name,)
])))



# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/03_expt.ipynb.

# %% auto 0
__all__ = ['ExpectedXath', 'ExpectedPath', 'ExpectedFile', 'ExpectedDir']

# %% ../nbs/03_expt.ipynb 6
#| export


# %% ../nbs/03_expt.ipynb 8
#| export


# %% ../nbs/03_expt.ipynb 10
#| export


# %% ../nbs/03_expt.ipynb 12
#| export


# %% ../nbs/03_expt.ipynb 14
from .leaf import LeafXath, LeafPath, LeafFile, LeafDir
from .mxns.expt import ExpectedMixin
from .mxns.kind import FileKindMixin, DirKindMixin

# %% ../nbs/03_expt.ipynb 16
class ExpectedXath(LeafXath, ExpectedMixin):
    ...

# %% ../nbs/03_expt.ipynb 18
class ExpectedPath(ExpectedXath):
    ...

# %% ../nbs/03_expt.ipynb 20
class ExpectedFile(FileKindMixin, ExpectedPath):
    file: LeafFile()
    ...

# %% ../nbs/03_expt.ipynb 22
# NOTE: could alternatively be defined as `ExpectedDir(LeafDir, ExpectedMixin)`
class ExpectedDir(DirKindMixin, ExpectedPath):
    dir: LeafDir()



# AUTOGENERATED! DO NOT EDIT! File to edit: ../../nbs/mxns/01_plib.ipynb.

# %% auto 0
__all__ = ['PathLibMixin']

# %% ../../nbs/mxns/01_plib.ipynb 6
import os, pathlib, tempfile, unittest

# %% ../../nbs/mxns/01_plib.ipynb 8
from typing import Callable, Optional

# %% ../../nbs/mxns/01_plib.ipynb 10
from nchr import DOT
from nlit import PATH
from pstr.util import toprivate

# %% ../../nbs/mxns/01_plib.ipynb 12
#| export

# %% ../../nbs/mxns/01_plib.ipynb 14
_PATH = toprivate(PATH)

# %% ../../nbs/mxns/01_plib.ipynb 15
class PathLibMixin(str, os.PathLike):
    # ---------------------------------------------------------------------------------------------------------
    # Is type
    # ---------------------------------------------------------------------------------------------------------
    def is_dir(self) -> bool:
        """Whether this path is a directory."""
        return self.path.is_dir()
    
    def is_file(self) -> bool:
        """Whether this path is a regular file (also True for symlinks pointing to regular files)."""
        return self.path.is_file()
    
    def is_fifo(self) -> bool:
        """Whether this path is a FIFO."""
        return self.path.is_fifo()
    
    def is_mount(self) -> bool:
        """Check if this path is a mount point"""
        return self.path.is_mount()
    
    def is_socket(self) -> bool:
        """Whether this path is a socket."""
        return self.path.is_socket()
    
    def is_symlink(self) -> bool:
        """Whether this path is a symbolic link."""
        return self.path.is_symlink()
    
    def is_junction(self) -> bool:
        """Whether this path is a junction."""
        return self.path.is_junction()
    
    def is_char_device(self) -> bool:
        """Whether this path is a character device."""
        return self.path.is_char_device()
    
    def is_block_device(self) -> bool:
        """Whether this path is a block device."""
        return self.path.is_block_device()
    
    # ---------------------------------------------------------------------------------------------------------
    # Properties
    # ---------------------------------------------------------------------------------------------------------
    @property
    def root(self):
        """The root of the path, if any."""
        return self.path.root
    
    @property
    def name(self):
        """The final path component, if any."""
        return self.path.name
    
    @property
    def stem(self):
        """The final path component, minus its last suffix."""
        return self.path.stem
    
    @property
    def drive(self):
        """The drive prefix (letter or UNC path), if any."""
        return self.path.drive
    
    @property
    def parts(self):
        """An object providing sequence-like access to the
        components in the filesystem path."""
        return self.path.parts
    
    @property
    def anchor(self):
        """The concatenation of the drive and root, or ''."""
        return self.path.anchor
    
    @property
    def suffix(self):
        """
        The final component's last suffix, if any.

        This includes the leading period. For example: '.txt'
        """
        return self.path.suffix
    
    @property
    def parent(self):
        """The logical parent of the path."""
        return self.path.parent
    
    @property
    def parents(self):
        """A sequence of this path's logical parents."""
        return self.path.parents
    
    @property
    def suffixes(self):
        """A list of the final component's suffixes, if any.
        These include the leading periods. For example: ['.tar', '.gz']
        """
        return self.path.suffixes
    
    @property
    def _flavour(self): return self.path._flavour
    
    # ---------------------------------------------------------------------------------------------------------
    # Methods
    # ---------------------------------------------------------------------------------------------------------
    def ls(self, n_max=None, file_type=None, file_exts=None): 
        return self.path.ls(n_max, file_type, file_exts)

    @classmethod
    def cwd(cls):
        """Return a new path pointing to the current working directory."""
        return cls(pathlib.Path.cwd())
    
    def open(
        self, mode: str = 'r', buffering: int = -1, encoding: Optional[str] = None,
        errors: Optional[str] = None, newline: Optional[str] = None
    ):
        """
        Open the file pointed by this path and return a file object, as
        the built-in open() function does.
        """
        return self.path.open(mode, buffering, encoding, errors, newline)
    
    def glob(self, pattern):
        """Iterate over this subtree and yield all existing files (of any
        kind, including directories) matching the given relative pattern.
        """
        return self.path.glob(pattern)
    
    @classmethod
    def home(cls):
        """Return a new path pointing to the user's home directory (as
        returned by os.path.expanduser('~')).
        """
        return cls(cls().path.home())
    
    def walk(self, top_down: bool = True, on_error: Optional[Callable] = None, follow_symlinks: bool  = False):
        """Walk the directory tree from this directory, similar to os.walk()."""
        return self.path.walk(top_down, on_error, follow_symlinks)
    
    def stat(self):
        """
        Return the result of the stat() system call on this path, like
        os.stat() does.
        """
        return self.path.stat()

    def lstat(self):
        """
        Like stat(), except if the path points to a symlink, the symlink's
        status information is returned, rather than its target's.
        """
        return self.path.lstat()
    
    def rmdir(self):
        """
        Remove this directory.  The directory must be empty.
        """
        return self.path.rmdir()
    
    def touch(self, mode: int = 438, exist_ok: bool = True):
        """
        Create this file with the given access mode, if it doesn't exist.
        """
        return self.path.touch(mode, exist_ok)
    
    def mkdir(self, mode: int = 511, parents: bool = False, exist_ok: bool = False):
        """
        Create a new directory at this given path.
        """
        return self.path.mkdir(mode, parents, exist_ok)
    
    def chmod(self, mode):
        """
        Change the permissions of the path, like os.chmod().
        """
        return self.path.chmod(mode)
    
    def owner(self):
        """
        Return the login name of the file owner.
        """
        return self.path.owner()
    
    def group(self):
        """
        Return the group name of the file gid.
        """
        return self.path.group()
    
    def rglob(self, pattern):
        """Recursively yield all existing files (of any kind, including
        directories) matching the given relative pattern, anywhere in
        this subtree.
        """
        return self.path.rglob(pattern)
    
    def match(self, pattern):
        """
        Return True if this path matches the given pattern.
        """
        return self.path.match(pattern)

    def delete(self): return self.path.delete()

    def lchmod(self, mode):
        """
        Like chmod(), except if the path points to a symlink, the symlink's
        permissions are changed, rather than its target's.
        """
        return self.path.lchmod(mode)
    
    def rename(self, target):
        """
        Rename this path to the target path.

        The target path may be absolute or relative. Relative paths are
        interpreted relative to the current working directory, *not* the
        directory of the Path object.

        Returns the new Path instance pointing to the target path.
        """
        return type(self)(self.path.rename(target))
    
    def unlink(self):
        """
        Remove this file or link.
        If the path is a directory, use rmdir() instead.
        """
        return self.path.unlink()
    
    def exists(self):
        """
        Whether this path exists.

        This method normally follows symlinks; to check whether a symlink exists,
        add the argument follow_symlinks=False.
        """
        return self.path.exists()
    
    def as_uri(self):
        """Return the path as a 'file' URI."""
        return self.path.as_uri()
    
    def resolve(self):
        """
        Make the path absolute, resolving all symlinks on the way and also
        normalizing it.
        """
        return type(self)(pathlib.Path(self).resolve())
    
    def link_to(self, target: pathlib.Path): return self.path.link_to(target)

    def relpath(self, start: Optional[pathlib.Path] = None): return self.path.relpath(start)

    def replace(self, target):
        """
        Rename this path to the target path, overwriting if that path exists.

        The target path may be absolute or relative. Relative paths are
        interpreted relative to the current working directory, *not* the
        directory of the Path object.

        Returns the new Path instance pointing to the target path.
        """
        return self.path.replace(target)
    
    def iterdir(self):
        """Yield path objects of the directory contents.

        The children are yielded in arbitrary order, and the
        special entries '.' and '..' are not included.
        """
        return self.path.iterdir()
    
    def as_posix(self) -> str:
        """Return the string representation of the path with forward (/)
        slashes."""
        return self.path.as_posix()
    
    def samefile(self, other):
        """Return whether other_path is the same or not as this file
        (as returned by os.path.samefile()).
        """
        return self.path.samefile(other)
    
    def joinpath(self, *other):
        """Combine this path with one or several arguments, and return a
        new path representing either a subpath (if all arguments are relative
        paths) or a totally different path (if one of the arguments is
        anchored).
        """
        return self.path.joinpath(*other)
    
    def mk_write(self, data, encoding: Optional[str] = None, errors: Optional[list] = None, mode: int = 511): 
        return self.path.mk_write(data, encoding, errors, mode)   
     
    def absolute(self):
        """Return an absolute version of this path by prepending the current
        working directory. No normalization or symlink resolution is performed.

        Use resolve() to get the canonical path to a file.
        """
        return type(self)(self.path.absolute())
    
    def readlink(self):
        """
        Return the path to which the symbolic link points.
        """
        return self.path.readlink()
    
    def _scandir(self): return self.path._scandir()

    def with_name(self, name):
        """Return a new path with the file name changed."""
        return type(self)(self.path.with_name(name))
    
    def with_stem(self, stem):
        """Return a new path with the stem changed."""
        return type(self)(self.path.with_stem(stem))
    
    def read_text(self, *args, **kwargs):
        """
        Open the file in text mode, read it, and close the file.
        """
        return self.path.read_text(*args, **kwargs)
    
    def read_json(self, encoding: Optional[str] = None, errors: Optional[list] = None): 
        return self.path.read_json(encoding, errors)

    def readlines(self, hint: int = -1, encoding: str = 'utf8'): 
        return self.path.readlines(hint, encoding)
    
    def with_segments(self, *segments):
        """Construct a new path object from any number of path-like objects.
        Subclasses may override this method to customize how new path objects
        are created from methods like `iterdir()`.
        """
        return type(self)(self.path.with_segments(*segments))

    def expanduser(self):
        """ Return a new path with expanded ~ and ~user constructs
        (as returned by os.path.expanduser)
        """
        return type(self)(self.path.expanduser())
    
    def read_bytes(self):
        """
        Open the file in bytes mode, read it, and close the file.
        """
        return self.path.read_bytes()
    
    def symlink_to(self, target, target_is_directory):
        """
        Make this path a symlink pointing to the target path.
        Note the order of arguments (link, target) is the reverse of os.symlink.
        """
        return self.path.symlink_to(target, target_is_directory)
    
    def write_text(self, data, encoding: Optional[str] = None, errors: Optional[str] = None, newline: Optional[str] = None):
        """
        Open the file in text mode, write to it, and close the file.
        """
        return self.path.write_text(data, encoding, errors, newline)

    def is_absolute(self) -> bool:
        """True if the path is absolute (has both a root and, if applicable,
        a drive)."""
        return self.path.is_absolute()
    
    def is_reserved(self) -> bool:
        """Return True if the path contains one of the special names reserved
        by the system, if any."""
        return self.path.is_reserved()
    
    def write_bytes(self, data):
        """
        Open the file in bytes mode, write to it, and close the file.
        """
        return self.path.write_bytes(data)
    
    def with_suffix(self, suffix):
        """Return a new path with the file suffix changed.  If the path
        has no suffix, add given suffix.  If the given suffix is an empty
        string, remove the suffix from the path.
        """
        return self.path.with_suffix(suffix)
    
    def relative_to(self, *other): 
        """Return the relative path to another path identified by the passed
        arguments.  If the operation is not possible (because this is not
        related to the other path), raise ValueError.

        The *walk_up* parameter controls whether `..` may be used to resolve
        the path.
        """
        return self.path.relative_to(*other)
    
    def hardlink_to(self, target):
        """
        Make this path a hard link pointing to the same file as *target*.

        Note the order of arguments (self, target) is the reverse of os.link's.
        """
        return self.path.hardlink_to(target)
    
    def is_relative_to(self, *other) -> bool:
        """Return True if the path is relative to another path or False."""
        return self.path.is_relative_to(*other)
    
    
    def _make_child_relpath(self, part): 
        return self.path._make_child_relpath(part)

    @classmethod
    def _parse_args(cls, args):
        return cls(pathlib.Path._parse_args(args))
            
    @classmethod
    def _from_parsed_parts(cls, drv, root, parts):        
        return cls(pathlib.Path._from_parsed_parts(drv, root, parts))
        
    @classmethod
    def _format_parsed_parts(cls, drv, root, parts):
        return cls(pathlib.Path._format_parsed_parts(drv, root, parts))

    def __eq__(self, other): 
        return self.path.__eq__(other)
        return self == aspath(other)

    def __lt__(self, other): 
        return self.path.__lt__(other)
        return self <  aspath(other)

    def __le__(self, other): 
        return self.path.__le__(other)
        return self <= aspath(other)

    def __gt__(self, other): 
        return self.path.__gt__(other)
        return self >  aspath(other)

    def __ge__(self, other): 
        return self.path.__ge__(other)
        return self >= aspath(other)


    def __hash__(self): return self.path.__hash__()

    def __bytes__(self):
        """Return the bytes representation of the path.  This is only
        recommended to use under Unix."""
        return self.path.__bytes__()
    
    def __fspath__(self): return self.path.__fspath__()

    def __reduce__(self): return (type(self), ) + self.path.__reduce__()

    def __truediv__(self, other): 
        return type(self)(self.path.__truediv__(other))

    def __rtruediv__(self, other): 
        return type(self)(self.path.__rtruediv__(other))

    def __new__(cls, path: Optional[str] = None, *args, **kwargs):
        obj = super().__new__(cls, (path or DOT))
        obj.path = pathlib.Path(obj)
        return obj
    
    def __init__(self, path = None, *args, **kwargs):
        ...
        self.path = pathlib.Path(path or self)

    @property 
    def path(self) -> pathlib.Path: return pathlib.Path(self or DOT)
    @property 
    def path(self) -> pathlib.Path: return getattr(self, _PATH, pathlib.Path(DOT))
    @path.setter
    def path(self, path: str): setattr(self, _PATH, pathlib.Path(path))
    
    @property
    def clsname(self): return type(self).__name__
    
    def __str__(self): return super().__str__()
    
    def __repr__(self): 
        return f'{self.clsname}({self.path})'



# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/xath',
                'doc_host': 'https://dsm-72.github.io',
                'git_url': 'https://github.com/dsm-72/xath',
                'lib_path': 'xath'},
  'syms': { 'xath.base': { 'xath.base.Dir': ('base.html#dir', 'xath/base.py'),
                           'xath.base.File': ('base.html#file', 'xath/base.py'),
                           'xath.base.Path': ('base.html#path', 'xath/base.py'),
                           'xath.base.Xath': ('base.html#xath', 'xath/base.py'),
                           'xath.base.Xath.__init__': ('base.html#xath.__init__', 'xath/base.py'),
                           'xath.base.Xath.__new__': ('base.html#xath.__new__', 'xath/base.py'),
                           'xath.base.Xath.full': ('base.html#xath.full', 'xath/base.py'),
                           'xath.base.Xath.kind': ('base.html#xath.kind', 'xath/base.py'),
                           'xath.base.Xath.makecopy': ('base.html#xath.makecopy', 'xath/base.py'),
                           'xath.base.Xath.name': ('base.html#xath.name', 'xath/base.py'),
                           'xath.base.Xath.pathname': ('base.html#xath.pathname', 'xath/base.py'),
                           'xath.base.Xath.tree': ('base.html#xath.tree', 'xath/base.py'),
                           'xath.base.Xath.update': ('base.html#xath.update', 'xath/base.py'),
                           'xath.base.Xath.view': ('base.html#xath.view', 'xath/base.py')},
            'xath.data': { 'xath.data.DataDir': ('data.html#datadir', 'xath/data.py'),
                           'xath.data.DataFile': ('data.html#datafile', 'xath/data.py'),
                           'xath.data.DataPath': ('data.html#datapath', 'xath/data.py'),
                           'xath.data.DataXath': ('data.html#dataxath', 'xath/data.py')},
            'xath.expt': { 'xath.expt.ExpectedDir': ('expt.html#expecteddir', 'xath/expt.py'),
                           'xath.expt.ExpectedFile': ('expt.html#expectedfile', 'xath/expt.py'),
                           'xath.expt.ExpectedPath': ('expt.html#expectedpath', 'xath/expt.py'),
                           'xath.expt.ExpectedXath': ('expt.html#expectedxath', 'xath/expt.py')},
            'xath.leaf': { 'xath.leaf.LeafDir': ('leaf.html#leafdir', 'xath/leaf.py'),
                           'xath.leaf.LeafFile': ('leaf.html#leaffile', 'xath/leaf.py'),
                           'xath.leaf.LeafPath': ('leaf.html#leafpath', 'xath/leaf.py'),
                           'xath.leaf.LeafXath': ('leaf.html#leafxath', 'xath/leaf.py'),
                           'xath.leaf.LeafXath.__init__': ('leaf.html#leafxath.__init__', 'xath/leaf.py'),
                           'xath.leaf.LeafXath.__rtruediv__': ('leaf.html#leafxath.__rtruediv__', 'xath/leaf.py'),
                           'xath.leaf.LeafXath.__truediv__': ('leaf.html#leafxath.__truediv__', 'xath/leaf.py'),
                           'xath.leaf.LeafXath.base': ('leaf.html#leafxath.base', 'xath/leaf.py'),
                           'xath.leaf.LeafXath.canbechild': ('leaf.html#leafxath.canbechild', 'xath/leaf.py'),
                           'xath.leaf.LeafXath.canbeparent': ('leaf.html#leafxath.canbeparent', 'xath/leaf.py'),
                           'xath.leaf.LeafXath.leaf': ('leaf.html#leafxath.leaf', 'xath/leaf.py'),
                           'xath.leaf.LeafXath.path': ('leaf.html#leafxath.path', 'xath/leaf.py')},
            'xath.mxns.data': { 'xath.mxns.data.DataMixin': ('mxns/data.html#datamixin', 'xath/mxns/data.py'),
                                'xath.mxns.data.DataMixin.load': ('mxns/data.html#datamixin.load', 'xath/mxns/data.py')},
            'xath.mxns.expt': { 'xath.mxns.expt.ExpectedMixin': ('mxns/expt.html#expectedmixin', 'xath/mxns/expt.py'),
                                'xath.mxns.expt.ExpectedMixin.__init__': ('mxns/expt.html#expectedmixin.__init__', 'xath/mxns/expt.py'),
                                'xath.mxns.expt.ExpectedMixin.isvalid': ('mxns/expt.html#expectedmixin.isvalid', 'xath/mxns/expt.py'),
                                'xath.mxns.expt.ExpectedMixin.makeprops': ('mxns/expt.html#expectedmixin.makeprops', 'xath/mxns/expt.py')},
            'xath.mxns.kind': { 'xath.mxns.kind.DirKindMixin': ('mxns/kind.html#dirkindmixin', 'xath/mxns/kind.py'),
                                'xath.mxns.kind.DirKindMixin.dirname': ('mxns/kind.html#dirkindmixin.dirname', 'xath/mxns/kind.py'),
                                'xath.mxns.kind.FileKindMixin': ('mxns/kind.html#filekindmixin', 'xath/mxns/kind.py'),
                                'xath.mxns.kind.FileKindMixin.filename': ('mxns/kind.html#filekindmixin.filename', 'xath/mxns/kind.py')},
            'xath.mxns.plib': { 'xath.mxns.plib.PathLibMixin': ('mxns/plib.html#pathlibmixin', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.__bytes__': ('mxns/plib.html#pathlibmixin.__bytes__', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.__eq__': ('mxns/plib.html#pathlibmixin.__eq__', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.__fspath__': ('mxns/plib.html#pathlibmixin.__fspath__', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.__ge__': ('mxns/plib.html#pathlibmixin.__ge__', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.__gt__': ('mxns/plib.html#pathlibmixin.__gt__', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.__hash__': ('mxns/plib.html#pathlibmixin.__hash__', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.__init__': ('mxns/plib.html#pathlibmixin.__init__', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.__le__': ('mxns/plib.html#pathlibmixin.__le__', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.__lt__': ('mxns/plib.html#pathlibmixin.__lt__', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.__new__': ('mxns/plib.html#pathlibmixin.__new__', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.__reduce__': ('mxns/plib.html#pathlibmixin.__reduce__', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.__repr__': ('mxns/plib.html#pathlibmixin.__repr__', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.__rtruediv__': ( 'mxns/plib.html#pathlibmixin.__rtruediv__',
                                                                              'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.__str__': ('mxns/plib.html#pathlibmixin.__str__', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.__truediv__': ('mxns/plib.html#pathlibmixin.__truediv__', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin._flavour': ('mxns/plib.html#pathlibmixin._flavour', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin._format_parsed_parts': ( 'mxns/plib.html#pathlibmixin._format_parsed_parts',
                                                                                      'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin._from_parsed_parts': ( 'mxns/plib.html#pathlibmixin._from_parsed_parts',
                                                                                    'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin._make_child_relpath': ( 'mxns/plib.html#pathlibmixin._make_child_relpath',
                                                                                     'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin._parse_args': ('mxns/plib.html#pathlibmixin._parse_args', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin._scandir': ('mxns/plib.html#pathlibmixin._scandir', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.absolute': ('mxns/plib.html#pathlibmixin.absolute', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.anchor': ('mxns/plib.html#pathlibmixin.anchor', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.as_posix': ('mxns/plib.html#pathlibmixin.as_posix', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.as_uri': ('mxns/plib.html#pathlibmixin.as_uri', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.chmod': ('mxns/plib.html#pathlibmixin.chmod', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.clsname': ('mxns/plib.html#pathlibmixin.clsname', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.cwd': ('mxns/plib.html#pathlibmixin.cwd', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.delete': ('mxns/plib.html#pathlibmixin.delete', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.drive': ('mxns/plib.html#pathlibmixin.drive', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.exists': ('mxns/plib.html#pathlibmixin.exists', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.expanduser': ('mxns/plib.html#pathlibmixin.expanduser', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.glob': ('mxns/plib.html#pathlibmixin.glob', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.group': ('mxns/plib.html#pathlibmixin.group', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.hardlink_to': ('mxns/plib.html#pathlibmixin.hardlink_to', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.home': ('mxns/plib.html#pathlibmixin.home', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.is_absolute': ('mxns/plib.html#pathlibmixin.is_absolute', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.is_block_device': ( 'mxns/plib.html#pathlibmixin.is_block_device',
                                                                                 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.is_char_device': ( 'mxns/plib.html#pathlibmixin.is_char_device',
                                                                                'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.is_dir': ('mxns/plib.html#pathlibmixin.is_dir', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.is_fifo': ('mxns/plib.html#pathlibmixin.is_fifo', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.is_file': ('mxns/plib.html#pathlibmixin.is_file', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.is_junction': ('mxns/plib.html#pathlibmixin.is_junction', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.is_mount': ('mxns/plib.html#pathlibmixin.is_mount', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.is_relative_to': ( 'mxns/plib.html#pathlibmixin.is_relative_to',
                                                                                'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.is_reserved': ('mxns/plib.html#pathlibmixin.is_reserved', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.is_socket': ('mxns/plib.html#pathlibmixin.is_socket', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.is_symlink': ('mxns/plib.html#pathlibmixin.is_symlink', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.iterdir': ('mxns/plib.html#pathlibmixin.iterdir', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.joinpath': ('mxns/plib.html#pathlibmixin.joinpath', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.lchmod': ('mxns/plib.html#pathlibmixin.lchmod', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.link_to': ('mxns/plib.html#pathlibmixin.link_to', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.ls': ('mxns/plib.html#pathlibmixin.ls', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.lstat': ('mxns/plib.html#pathlibmixin.lstat', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.match': ('mxns/plib.html#pathlibmixin.match', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.mk_write': ('mxns/plib.html#pathlibmixin.mk_write', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.mkdir': ('mxns/plib.html#pathlibmixin.mkdir', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.name': ('mxns/plib.html#pathlibmixin.name', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.open': ('mxns/plib.html#pathlibmixin.open', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.owner': ('mxns/plib.html#pathlibmixin.owner', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.parent': ('mxns/plib.html#pathlibmixin.parent', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.parents': ('mxns/plib.html#pathlibmixin.parents', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.parts': ('mxns/plib.html#pathlibmixin.parts', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.path': ('mxns/plib.html#pathlibmixin.path', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.read_bytes': ('mxns/plib.html#pathlibmixin.read_bytes', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.read_json': ('mxns/plib.html#pathlibmixin.read_json', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.read_text': ('mxns/plib.html#pathlibmixin.read_text', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.readlines': ('mxns/plib.html#pathlibmixin.readlines', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.readlink': ('mxns/plib.html#pathlibmixin.readlink', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.relative_to': ('mxns/plib.html#pathlibmixin.relative_to', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.relpath': ('mxns/plib.html#pathlibmixin.relpath', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.rename': ('mxns/plib.html#pathlibmixin.rename', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.replace': ('mxns/plib.html#pathlibmixin.replace', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.resolve': ('mxns/plib.html#pathlibmixin.resolve', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.rglob': ('mxns/plib.html#pathlibmixin.rglob', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.rmdir': ('mxns/plib.html#pathlibmixin.rmdir', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.root': ('mxns/plib.html#pathlibmixin.root', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.samefile': ('mxns/plib.html#pathlibmixin.samefile', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.stat': ('mxns/plib.html#pathlibmixin.stat', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.stem': ('mxns/plib.html#pathlibmixin.stem', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.suffix': ('mxns/plib.html#pathlibmixin.suffix', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.suffixes': ('mxns/plib.html#pathlibmixin.suffixes', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.symlink_to': ('mxns/plib.html#pathlibmixin.symlink_to', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.touch': ('mxns/plib.html#pathlibmixin.touch', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.unlink': ('mxns/plib.html#pathlibmixin.unlink', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.walk': ('mxns/plib.html#pathlibmixin.walk', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.with_name': ('mxns/plib.html#pathlibmixin.with_name', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.with_segments': ( 'mxns/plib.html#pathlibmixin.with_segments',
                                                                               'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.with_stem': ('mxns/plib.html#pathlibmixin.with_stem', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.with_suffix': ('mxns/plib.html#pathlibmixin.with_suffix', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.write_bytes': ('mxns/plib.html#pathlibmixin.write_bytes', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.write_text': ('mxns/plib.html#pathlibmixin.write_text', 'xath/mxns/plib.py')},
            'xath.mxns.reqr': { 'xath.mxns.reqr.RequiredMixin': ('mxns/reqr.html#requiredmixin', 'xath/mxns/reqr.py'),
                                'xath.mxns.reqr.RequiredMixin.isvalid': ('mxns/reqr.html#requiredmixin.isvalid', 'xath/mxns/reqr.py'),
                                'xath.mxns.reqr.RequiredMixin.optional': ('mxns/reqr.html#requiredmixin.optional', 'xath/mxns/reqr.py')},
            'xath.name': { 'xath.name.NamedDir': ('name.html#nameddir', 'xath/name.py'),
                           'xath.name.NamedFile': ('name.html#namedfile', 'xath/name.py'),
                           'xath.name.NamedPath': ('name.html#namedpath', 'xath/name.py'),
                           'xath.name.NamedXath': ('name.html#namedxath', 'xath/name.py'),
                           'xath.name.NamedXath.__init__': ('name.html#namedxath.__init__', 'xath/name.py')},
            'xath.plib.lib': { 'xath.plib.lib.Path': ('plib/lib.html#path', 'xath/plib/lib.py'),
                               'xath.plib.lib.Path.__enter__': ('plib/lib.html#path.__enter__', 'xath/plib/lib.py'),
                               'xath.plib.lib.Path.__exit__': ('plib/lib.html#path.__exit__', 'xath/plib/lib.py'),
                               'xath.plib.lib.Path.__init__': ('plib/lib.html#path.__init__', 'xath/plib/lib.py'),
                               'xath.plib.lib.Path.__new__': ('plib/lib.html#path.__new__', 'xath/plib/lib.py'),
                               'xath.plib.lib.Path._make_child_relpath': ('plib/lib.html#path._make_child_relpath', 'xath/plib/lib.py'),
                               'xath.plib.lib.Path._scandir': ('plib/lib.html#path._scandir', 'xath/plib/lib.py'),
                               'xath.plib.lib.Path.absolute': ('plib/lib.html#path.absolute', 'xath/plib/lib.py'),
                               'xath.plib.lib.Path.chmod': ('plib/lib.html#path.chmod', 'xath/plib/lib.py'),
                               'xath.plib.lib.Path.cwd': ('plib/lib.html#path.cwd', 'xath/plib/lib.py'),
                               'xath.plib.lib.Path.exists': ('plib/lib.html#path.exists', 'xath/plib/lib.py'),
                               'xath.plib.lib.Path.expanduser': ('plib/lib.html#path.expanduser', 'xath/plib/lib.py'),
                               'xath.plib.lib.Path.glob': ('plib/lib.html#path.glob', 'xath/plib/lib.py'),
                               'xath.plib.lib.Path.group': ('plib/lib.html#path.group', 'xath/plib/lib.py'),
                               'xath.plib.lib.Path.hardlink_to': ('plib/lib.html#path.hardlink_to', 'xath/plib/lib.py'),
                               'xath.plib.lib.Path.home': ('plib/lib.html#path.home', 'xath/plib/lib.py'),
                               'xath.plib.lib.Path.is_block_device': ('plib/lib.html#path.is_block_device', 'xath/plib/lib.py'),
                               'xath.plib.lib.Path.is_char_device': ('plib/lib.html#path.is_char_device', 'xath/plib/lib.py'),
                               'xath.plib.lib.Path.is_dir': ('plib/lib.html#path.is_dir', 'xath/plib/lib.py'),
                               'xath.plib.lib.Path.is_fifo': ('plib/lib.html#path.is_fifo', 'xath/plib/lib.py'),
                               'xath.plib.lib.Path.is_file': ('plib/lib.html#path.is_file', 'xath/plib/lib.py'),
                               'xath.plib.lib.Path.is_junction': ('plib/lib.html#path.is_junction', 'xath/plib/lib.py'),
                               'xath.plib.lib.Path.is_mount': ('plib/lib.html#path.is_mount', 'xath/plib/lib.py'),
                               'xath.plib.lib.Path.is_socket': ('plib/lib.html#path.is_socket', 'xath/plib/lib.py'),
                               'xath.plib.lib.Path.is_symlink': ('plib/lib.html#path.is_symlink', 'xath/plib/lib.py'),
                               'xath.plib.lib.Path.iterdir': ('plib/lib.html#path.iterdir', 'xath/plib/lib.py'),
                               'xath.plib.lib.Path.lchmod': ('plib/lib.html#path.lchmod', 'xath/plib/lib.py'),
                               'xath.plib.lib.Path.lstat': ('plib/lib.html#path.lstat', 'xath/plib/lib.py'),
                               'xath.plib.lib.Path.mkdir': ('plib/lib.html#path.mkdir', 'xath/plib/lib.py'),
                               'xath.plib.lib.Path.open': ('plib/lib.html#path.open', 'xath/plib/lib.py'),
                               'xath.plib.lib.Path.owner': ('plib/lib.html#path.owner', 'xath/plib/lib.py'),
                               'xath.plib.lib.Path.read_bytes': ('plib/lib.html#path.read_bytes', 'xath/plib/lib.py'),
                               'xath.plib.lib.Path.read_text': ('plib/lib.html#path.read_text', 'xath/plib/lib.py'),
                               'xath.plib.lib.Path.readlink': ('plib/lib.html#path.readlink', 'xath/plib/lib.py'),
                               'xath.plib.lib.Path.rename': ('plib/lib.html#path.rename', 'xath/plib/lib.py'),
                               'xath.plib.lib.Path.replace': ('plib/lib.html#path.replace', 'xath/plib/lib.py'),
                               'xath.plib.lib.Path.resolve': ('plib/lib.html#path.resolve', 'xath/plib/lib.py'),
                               'xath.plib.lib.Path.rglob': ('plib/lib.html#path.rglob', 'xath/plib/lib.py'),
                               'xath.plib.lib.Path.rmdir': ('plib/lib.html#path.rmdir', 'xath/plib/lib.py'),
                               'xath.plib.lib.Path.samefile': ('plib/lib.html#path.samefile', 'xath/plib/lib.py'),
                               'xath.plib.lib.Path.stat': ('plib/lib.html#path.stat', 'xath/plib/lib.py'),
                               'xath.plib.lib.Path.symlink_to': ('plib/lib.html#path.symlink_to', 'xath/plib/lib.py'),
                               'xath.plib.lib.Path.touch': ('plib/lib.html#path.touch', 'xath/plib/lib.py'),
                               'xath.plib.lib.Path.unlink': ('plib/lib.html#path.unlink', 'xath/plib/lib.py'),
                               'xath.plib.lib.Path.walk': ('plib/lib.html#path.walk', 'xath/plib/lib.py'),
                               'xath.plib.lib.Path.write_bytes': ('plib/lib.html#path.write_bytes', 'xath/plib/lib.py'),
                               'xath.plib.lib.Path.write_text': ('plib/lib.html#path.write_text', 'xath/plib/lib.py'),
                               'xath.plib.lib.PosixPath': ('plib/lib.html#posixpath', 'xath/plib/lib.py'),
                               'xath.plib.lib.PurePath': ('plib/lib.html#purepath', 'xath/plib/lib.py'),
                               'xath.plib.lib.PurePath.__bytes__': ('plib/lib.html#purepath.__bytes__', 'xath/plib/lib.py'),
                               'xath.plib.lib.PurePath.__eq__': ('plib/lib.html#purepath.__eq__', 'xath/plib/lib.py'),
                               'xath.plib.lib.PurePath.__fspath__': ('plib/lib.html#purepath.__fspath__', 'xath/plib/lib.py'),
                               'xath.plib.lib.PurePath.__ge__': ('plib/lib.html#purepath.__ge__', 'xath/plib/lib.py'),
                               'xath.plib.lib.PurePath.__gt__': ('plib/lib.html#purepath.__gt__', 'xath/plib/lib.py'),
                               'xath.plib.lib.PurePath.__hash__': ('plib/lib.html#purepath.__hash__', 'xath/plib/lib.py'),
                               'xath.plib.lib.PurePath.__init__': ('plib/lib.html#purepath.__init__', 'xath/plib/lib.py'),
                               'xath.plib.lib.PurePath.__le__': ('plib/lib.html#purepath.__le__', 'xath/plib/lib.py'),
                               'xath.plib.lib.PurePath.__lt__': ('plib/lib.html#purepath.__lt__', 'xath/plib/lib.py'),
                               'xath.plib.lib.PurePath.__new__': ('plib/lib.html#purepath.__new__', 'xath/plib/lib.py'),
                               'xath.plib.lib.PurePath.__reduce__': ('plib/lib.html#purepath.__reduce__', 'xath/plib/lib.py'),
                               'xath.plib.lib.PurePath.__repr__': ('plib/lib.html#purepath.__repr__', 'xath/plib/lib.py'),
                               'xath.plib.lib.PurePath.__rtruediv__': ('plib/lib.html#purepath.__rtruediv__', 'xath/plib/lib.py'),
                               'xath.plib.lib.PurePath.__str__': ('plib/lib.html#purepath.__str__', 'xath/plib/lib.py'),
                               'xath.plib.lib.PurePath.__truediv__': ('plib/lib.html#purepath.__truediv__', 'xath/plib/lib.py'),
                               'xath.plib.lib.PurePath._format_parsed_parts': ( 'plib/lib.html#purepath._format_parsed_parts',
                                                                                'xath/plib/lib.py'),
                               'xath.plib.lib.PurePath._from_parsed_parts': ( 'plib/lib.html#purepath._from_parsed_parts',
                                                                              'xath/plib/lib.py'),
                               'xath.plib.lib.PurePath._lines': ('plib/lib.html#purepath._lines', 'xath/plib/lib.py'),
                               'xath.plib.lib.PurePath._load_parts': ('plib/lib.html#purepath._load_parts', 'xath/plib/lib.py'),
                               'xath.plib.lib.PurePath._parse_path': ('plib/lib.html#purepath._parse_path', 'xath/plib/lib.py'),
                               'xath.plib.lib.PurePath._parts_normcase': ('plib/lib.html#purepath._parts_normcase', 'xath/plib/lib.py'),
                               'xath.plib.lib.PurePath._str_normcase': ('plib/lib.html#purepath._str_normcase', 'xath/plib/lib.py'),
                               'xath.plib.lib.PurePath._tail': ('plib/lib.html#purepath._tail', 'xath/plib/lib.py'),
                               'xath.plib.lib.PurePath.anchor': ('plib/lib.html#purepath.anchor', 'xath/plib/lib.py'),
                               'xath.plib.lib.PurePath.as_posix': ('plib/lib.html#purepath.as_posix', 'xath/plib/lib.py'),
                               'xath.plib.lib.PurePath.as_uri': ('plib/lib.html#purepath.as_uri', 'xath/plib/lib.py'),
                               'xath.plib.lib.PurePath.drive': ('plib/lib.html#purepath.drive', 'xath/plib/lib.py'),
                               'xath.plib.lib.PurePath.is_absolute': ('plib/lib.html#purepath.is_absolute', 'xath/plib/lib.py'),
                               'xath.plib.lib.PurePath.is_relative_to': ('plib/lib.html#purepath.is_relative_to', 'xath/plib/lib.py'),
                               'xath.plib.lib.PurePath.is_reserved': ('plib/lib.html#purepath.is_reserved', 'xath/plib/lib.py'),
                               'xath.plib.lib.PurePath.joinpath': ('plib/lib.html#purepath.joinpath', 'xath/plib/lib.py'),
                               'xath.plib.lib.PurePath.match': ('plib/lib.html#purepath.match', 'xath/plib/lib.py'),
                               'xath.plib.lib.PurePath.name': ('plib/lib.html#purepath.name', 'xath/plib/lib.py'),
                               'xath.plib.lib.PurePath.parent': ('plib/lib.html#purepath.parent', 'xath/plib/lib.py'),
                               'xath.plib.lib.PurePath.parents': ('plib/lib.html#purepath.parents', 'xath/plib/lib.py'),
                               'xath.plib.lib.PurePath.parts': ('plib/lib.html#purepath.parts', 'xath/plib/lib.py'),
                               'xath.plib.lib.PurePath.relative_to': ('plib/lib.html#purepath.relative_to', 'xath/plib/lib.py'),
                               'xath.plib.lib.PurePath.root': ('plib/lib.html#purepath.root', 'xath/plib/lib.py'),
                               'xath.plib.lib.PurePath.stem': ('plib/lib.html#purepath.stem', 'xath/plib/lib.py'),
                               'xath.plib.lib.PurePath.suffix': ('plib/lib.html#purepath.suffix', 'xath/plib/lib.py'),
                               'xath.plib.lib.PurePath.suffixes': ('plib/lib.html#purepath.suffixes', 'xath/plib/lib.py'),
                               'xath.plib.lib.PurePath.with_name': ('plib/lib.html#purepath.with_name', 'xath/plib/lib.py'),
                               'xath.plib.lib.PurePath.with_segments': ('plib/lib.html#purepath.with_segments', 'xath/plib/lib.py'),
                               'xath.plib.lib.PurePath.with_stem': ('plib/lib.html#purepath.with_stem', 'xath/plib/lib.py'),
                               'xath.plib.lib.PurePath.with_suffix': ('plib/lib.html#purepath.with_suffix', 'xath/plib/lib.py'),
                               'xath.plib.lib.PurePosixPath': ('plib/lib.html#pureposixpath', 'xath/plib/lib.py'),
                               'xath.plib.lib.PureWindowsPath': ('plib/lib.html#purewindowspath', 'xath/plib/lib.py'),
                               'xath.plib.lib.WindowsPath': ('plib/lib.html#windowspath', 'xath/plib/lib.py'),
                               'xath.plib.lib._DoubleRecursiveWildcardSelector': ( 'plib/lib.html#_doublerecursivewildcardselector',
                                                                                   'xath/plib/lib.py'),
                               'xath.plib.lib._DoubleRecursiveWildcardSelector._select_from': ( 'plib/lib.html#_doublerecursivewildcardselector._select_from',
                                                                                                'xath/plib/lib.py'),
                               'xath.plib.lib._ParentSelector': ('plib/lib.html#_parentselector', 'xath/plib/lib.py'),
                               'xath.plib.lib._ParentSelector.__init__': ('plib/lib.html#_parentselector.__init__', 'xath/plib/lib.py'),
                               'xath.plib.lib._ParentSelector._select_from': ( 'plib/lib.html#_parentselector._select_from',
                                                                               'xath/plib/lib.py'),
                               'xath.plib.lib._PathParents': ('plib/lib.html#_pathparents', 'xath/plib/lib.py'),
                               'xath.plib.lib._PathParents.__getitem__': ('plib/lib.html#_pathparents.__getitem__', 'xath/plib/lib.py'),
                               'xath.plib.lib._PathParents.__init__': ('plib/lib.html#_pathparents.__init__', 'xath/plib/lib.py'),
                               'xath.plib.lib._PathParents.__len__': ('plib/lib.html#_pathparents.__len__', 'xath/plib/lib.py'),
                               'xath.plib.lib._PathParents.__repr__': ('plib/lib.html#_pathparents.__repr__', 'xath/plib/lib.py'),
                               'xath.plib.lib._RecursiveWildcardSelector': ('plib/lib.html#_recursivewildcardselector', 'xath/plib/lib.py'),
                               'xath.plib.lib._RecursiveWildcardSelector.__init__': ( 'plib/lib.html#_recursivewildcardselector.__init__',
                                                                                      'xath/plib/lib.py'),
                               'xath.plib.lib._RecursiveWildcardSelector._iterate_directories': ( 'plib/lib.html#_recursivewildcardselector._iterate_directories',
                                                                                                  'xath/plib/lib.py'),
                               'xath.plib.lib._RecursiveWildcardSelector._select_from': ( 'plib/lib.html#_recursivewildcardselector._select_from',
                                                                                          'xath/plib/lib.py'),
                               'xath.plib.lib._Selector': ('plib/lib.html#_selector', 'xath/plib/lib.py'),
                               'xath.plib.lib._Selector.__init__': ('plib/lib.html#_selector.__init__', 'xath/plib/lib.py'),
                               'xath.plib.lib._Selector.select_from': ('plib/lib.html#_selector.select_from', 'xath/plib/lib.py'),
                               'xath.plib.lib._TerminatingSelector': ('plib/lib.html#_terminatingselector', 'xath/plib/lib.py'),
                               'xath.plib.lib._TerminatingSelector._select_from': ( 'plib/lib.html#_terminatingselector._select_from',
                                                                                    'xath/plib/lib.py'),
                               'xath.plib.lib._WildcardSelector': ('plib/lib.html#_wildcardselector', 'xath/plib/lib.py'),
                               'xath.plib.lib._WildcardSelector.__init__': ('plib/lib.html#_wildcardselector.__init__', 'xath/plib/lib.py'),
                               'xath.plib.lib._WildcardSelector._select_from': ( 'plib/lib.html#_wildcardselector._select_from',
                                                                                 'xath/plib/lib.py'),
                               'xath.plib.lib._compile_pattern': ('plib/lib.html#_compile_pattern', 'xath/plib/lib.py'),
                               'xath.plib.lib._compile_pattern_lines': ('plib/lib.html#_compile_pattern_lines', 'xath/plib/lib.py'),
                               'xath.plib.lib._ignore_error': ('plib/lib.html#_ignore_error', 'xath/plib/lib.py'),
                               'xath.plib.lib._is_case_sensitive': ('plib/lib.html#_is_case_sensitive', 'xath/plib/lib.py'),
                               'xath.plib.lib._make_selector': ('plib/lib.html#_make_selector', 'xath/plib/lib.py'),
                               'xath.plib.lib.calc_raw_paths': ('plib/lib.html#calc_raw_paths', 'xath/plib/lib.py'),
                               'xath.plib.lib.psx_splitroot': ('plib/lib.html#psx_splitroot', 'xath/plib/lib.py'),
                               'xath.plib.lib.wdx_splitroot': ('plib/lib.html#wdx_splitroot', 'xath/plib/lib.py')},
            'xath.plib.psx': { 'xath.plib.psx._get_sep': ('plib/psx.html#_get_sep', 'xath/plib/psx.py'),
                               'xath.plib.psx._joinrealpath': ('plib/psx.html#_joinrealpath', 'xath/plib/psx.py'),
                               'xath.plib.psx.abspath': ('plib/psx.html#abspath', 'xath/plib/psx.py'),
                               'xath.plib.psx.basename': ('plib/psx.html#basename', 'xath/plib/psx.py'),
                               'xath.plib.psx.commonpath': ('plib/psx.html#commonpath', 'xath/plib/psx.py'),
                               'xath.plib.psx.dirname': ('plib/psx.html#dirname', 'xath/plib/psx.py'),
                               'xath.plib.psx.expanduser': ('plib/psx.html#expanduser', 'xath/plib/psx.py'),
                               'xath.plib.psx.expandvars': ('plib/psx.html#expandvars', 'xath/plib/psx.py'),
                               'xath.plib.psx.isabs': ('plib/psx.html#isabs', 'xath/plib/psx.py'),
                               'xath.plib.psx.isjunction': ('plib/psx.html#isjunction', 'xath/plib/psx.py'),
                               'xath.plib.psx.ismount': ('plib/psx.html#ismount', 'xath/plib/psx.py'),
                               'xath.plib.psx.join': ('plib/psx.html#join', 'xath/plib/psx.py'),
                               'xath.plib.psx.lexists': ('plib/psx.html#lexists', 'xath/plib/psx.py'),
                               'xath.plib.psx.normcase': ('plib/psx.html#normcase', 'xath/plib/psx.py'),
                               'xath.plib.psx.realpath': ('plib/psx.html#realpath', 'xath/plib/psx.py'),
                               'xath.plib.psx.relpath': ('plib/psx.html#relpath', 'xath/plib/psx.py'),
                               'xath.plib.psx.split': ('plib/psx.html#split', 'xath/plib/psx.py'),
                               'xath.plib.psx.splitdrive': ('plib/psx.html#splitdrive', 'xath/plib/psx.py'),
                               'xath.plib.psx.splitext': ('plib/psx.html#splitext', 'xath/plib/psx.py'),
                               'xath.plib.psx.splitroot': ('plib/psx.html#splitroot', 'xath/plib/psx.py')},
            'xath.plib.wdx': { 'xath.plib.wdx._abspath_fallback': ('plib/wdx.html#_abspath_fallback', 'xath/plib/wdx.py'),
                               'xath.plib.wdx._get_bothseps': ('plib/wdx.html#_get_bothseps', 'xath/plib/wdx.py'),
                               'xath.plib.wdx.basename': ('plib/wdx.html#basename', 'xath/plib/wdx.py'),
                               'xath.plib.wdx.commonpath': ('plib/wdx.html#commonpath', 'xath/plib/wdx.py'),
                               'xath.plib.wdx.dirname': ('plib/wdx.html#dirname', 'xath/plib/wdx.py'),
                               'xath.plib.wdx.expanduser': ('plib/wdx.html#expanduser', 'xath/plib/wdx.py'),
                               'xath.plib.wdx.expandvars': ('plib/wdx.html#expandvars', 'xath/plib/wdx.py'),
                               'xath.plib.wdx.isabs': ('plib/wdx.html#isabs', 'xath/plib/wdx.py'),
                               'xath.plib.wdx.ismount': ('plib/wdx.html#ismount', 'xath/plib/wdx.py'),
                               'xath.plib.wdx.join': ('plib/wdx.html#join', 'xath/plib/wdx.py'),
                               'xath.plib.wdx.lexists': ('plib/wdx.html#lexists', 'xath/plib/wdx.py'),
                               'xath.plib.wdx.relpath': ('plib/wdx.html#relpath', 'xath/plib/wdx.py'),
                               'xath.plib.wdx.split': ('plib/wdx.html#split', 'xath/plib/wdx.py'),
                               'xath.plib.wdx.splitdrive': ('plib/wdx.html#splitdrive', 'xath/plib/wdx.py'),
                               'xath.plib.wdx.splitext': ('plib/wdx.html#splitext', 'xath/plib/wdx.py'),
                               'xath.plib.wdx.splitroot': ('plib/wdx.html#splitroot', 'xath/plib/wdx.py')}}}
